@@ -7,12 +7,12 @@ RDF::Query::Parser::SPARQL - SPARQL Parser.
 
 =head1 VERSION
 
-This document describes RDF::Query::Parser::SPARQL version 2.912.
+This document describes RDF::Query::Parser::SPARQL version 2.915.
 
 =head1 SYNOPSIS
 
  use RDF::Query::Parser::SPARQL;
- my $parser	= RDF::Query::Parse::SPARQL->new();
+ my $parser	= RDF::Query::Parser::SPARQL->new();
  my $iterator = $parser->parse( $query, $base_uri );
 
 =head1 DESCRIPTION
@@ -47,7 +47,7 @@ use Scalar::Util qw(blessed looks_like_number);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.912';
+	$VERSION	= '2.915';
 }
 
 ######################################################################
